Package: pystr
Type: Package
Title: Python String Methods in R
Version: 2.0.0
Date: 2016-05-10
Author: Nicole White [aut, cre], Oliver Keyes [aut]
URL: https://github.com/nicolewhite/pystr
BugReports: https://github.com/nicolewhite/pystr/issues
Description: String operations the Python way - a package for those of us who
    miss Python's string methods while we're working in R.
Maintainer: Nicole White <nicole.m.white@outlook.com>
License: MIT + file LICENSE
LazyData: TRUE
Suggests: testthat
LinkingTo: Rcpp
Imports: Rcpp
RoxygenNote: 5.0.1
NeedsCompilation: yes
Packaged: 2016-05-11 06:08:43 UTC; nicolewhite
Repository: CRAN
Date/Publication: 2016-05-11 12:06:48
Built: R 4.4.0; i386-portbld-midnightbsd4.0; 2026-05-15 05:15:41 UTC; unix
